@@ -65,11 +65,9 @@ fi
 command_arguments=${command_arguments:-}
 
 # Always ensure yum has full cache
-check_for_yum_lock
 yum makecache || echo "Yum makecache failed. This can cause failure later on."
 
 # yum check-update exits 100 if updates are available
-check_for_yum_lock
 set +e
 check_update=$(yum check-update 2>&1)
 check_update_exit=$?
@@ -84,31 +82,12 @@ elif [[ "$check_update_exit" != "100" ]]; then
     exit 0
 fi
 
-# TODO: FIXME: remove this in Pike.
-# Hack around mod_ssl update and puppet https://bugs.launchpad.net/tripleo/+bug/1682448
-touch /etc/httpd/conf.d/ssl.conf
-
-# Fix the redis/rabbit resource start/stop timeouts. See https://bugs.launchpad.net/tripleo/+bug/1633455
-# and https://bugs.launchpad.net/tripleo/+bug/1634851
-if [[ "$pacemaker_status" == "active" && \
-      "$(hiera -c /etc/puppet/hiera.yaml bootstrap_nodeid)" = "$(facter hostname)" ]] ; then
-    if pcs resource show rabbitmq | grep -E "start.*timeout=100"; then
-        pcs resource update rabbitmq op start timeout=200s
-    fi
-    if pcs resource show rabbitmq | grep -E "stop.*timeout=90"; then
-        pcs resource update rabbitmq op stop timeout=200s
-    fi
-    if pcs resource show redis | grep -E "start.*timeout=120"; then
-        pcs resource update redis op start timeout=200s
-    fi
-    if pcs resource show redis | grep -E "stop.*timeout=120"; then
-        pcs resource update redis op stop timeout=200s
-    fi
-fi
-
 # special case https://bugs.launchpad.net/tripleo/+bug/1635205 +bug/1669714
 special_case_ovs_upgrade_if_needed
 
+# Resolve any RPM dependency issues before attempting the update
+yum_pre_update
+
 if [[ "$pacemaker_status" == "active" ]] ; then
     echo "Pacemaker running, stopping cluster node and doing full package update"
     node_count=$(pcs status xml | grep -o "<nodes_configured.*/>" | grep -o 'number="[0-9]*"' | grep -o "[0-9]*")
